@@ -1,6 +1,6 @@
 context("Just testing PSEAAC functionality")
 
-test_that("Check whether length of APAAC vector is correct",{
+test_that("Check whether length of PSEAAC vector is correct",{
   apaac<-PSEAAC(seqs = "AYCMLWTIL",lambda = 3,l = 2)
   lenApaac<-length(apaac)
   expectedLen<-400+(3)
